Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manifest ¶
type Manifest struct {
// Manifests is a list of Updatecli manifest file
Manifests []string
// Values is a list of Updatecli value file
Values []string
// ValuesInline is a list of inline values for templating, accepted valid json/yaml string
ValuesInline []string
// Secrets is a list of Updatecli secret file
Secrets []string
// GraphOutput is a path to output the manifest graph to
GraphOutput string
}
Click to show internal directories.
Click to hide internal directories.