Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func InitBin ¶ added in v0.44.0
InitBin creates a bin directory used by updatecli to store and execute command
func InitReport ¶ added in v0.99.0
InitReport creates a report directory used by updatecli to store reports
func InitUnique ¶ added in v0.115.0
func InitUnique() error
InitUnique sets a unique temporary directory for this Updatecli execution. This is useful when running multiple Updatecli instances in parallel targeting the same repository, to avoid conflicts between cloned directories.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.