Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ChartValidFiles specifies accepted Helm chart metadata filename ChartValidFiles [2]string = [2]string{"Chart.yaml", "Chart.yml"} )
Functions ¶
This section is empty.
Types ¶
type Helm ¶
type Helm struct {
// contains filtered or unexported fields
}
Helm hold all information needed to generate helm manifest.
func (Helm) DiscoverManifests ¶
type MatchingRule ¶
type MatchingRule struct {
// Path specifies a Helm chart path pattern, the pattern requires to match all of name, not just a subpart of the path.
Path string
// Dependencies specifies a list of dependencies pattern.
Dependencies map[string]string
// Containers specifies a list of containers pattern.
Containers map[string]string
}
MatchingRule allows to specifies rules to identify manifest
type MatchingRules ¶
type MatchingRules []MatchingRule
func (MatchingRules) Validate ¶ added in v0.115.0
func (m MatchingRules) Validate() error
Validate checks that each matching rule has at least one non-empty field. Returns an error if any rule has no valid fields specified.
type Spec ¶
type Spec struct {
// auths provides a map of registry credentials where the key is the registry URL without scheme
// if empty, updatecli relies on OCI credentials such as the one used by Docker.
//
// example:
//
// ---
// auths:
// "ghcr.io":
// token: "xxx"
// "index.docker.io":
// username: "admin"
// password: "password"
// ---
//
Auths map[string]docker.InlineKeyChain `yaml:",omitempty"`
// digest provides a parameter to specify if the generated manifest should use a digest on top of the tag when updating container.
Digest *bool `yaml:",omitempty"`
// ignorecontainer disables OCI container tag update when set to true
IgnoreContainer bool `yaml:",omitempty"`
// ignorechartdependency disables Helm chart dependencies update when set to true
IgnoreChartDependency bool `yaml:",omitempty"`
// Ignore specifies rule to ignore Helm chart update.
Ignore MatchingRules `yaml:",omitempty"`
// rootdir defines the root directory used to recursively search for Helm Chart
RootDir string `yaml:",omitempty"`
// only specify required rule(s) to restrict Helm chart update.
Only MatchingRules `yaml:",omitempty"`
// versionfilter provides parameters to specify the version pattern used when generating manifest.
//
// More information available at
// https://www.updatecli.io/docs/core/versionfilter/
//
// kind - semver
// versionfilter of kind `semver` uses semantic versioning as version filtering
// pattern accepts one of:
// `patch` - patch only update patch version
// `minor` - minor only update minor version
// `major` - major only update major versions
// `a version constraint` such as `>= 1.0.0`
//
// kind - regex
// versionfilter of kind `regex` uses regular expression as version filtering
// pattern accepts a valid regular expression
//
// example:
// “`
// versionfilter:
// kind: semver
// pattern: minor
// “`
//
// More version filter available at https://www.updatecli.io/docs/core/versionfilter/
//
VersionFilter version.Filter `yaml:",omitempty"`
// [target] Defines if a Chart should be packaged or not.
SkipPackaging bool `yaml:",omitempty"`
// [target] Defines if a Chart changes, triggers, or not, a Chart version update, accepted values is a comma separated list of "none,major,minor,patch"
VersionIncrement string `yaml:",omitempty"`
}
Spec defines the Helm parameters.
Click to show internal directories.
Click to hide internal directories.