dockerdigest

package
v0.115.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DockerDigest

type DockerDigest struct {
	// contains filtered or unexported fields
}

DockerDigest defines a resource of kind "dockerDigest" to interact with a docker registry

func New

func New(spec interface{}) (*DockerDigest, error)

New returns a reference to a newly initialized DockerDigest object from a Spec or an error if the provided Spec triggers a validation error.

func (*DockerDigest) Changelog

func (d *DockerDigest) Changelog(from, to string) *result.Changelogs

Changelog returns the changelog for this resource, or an empty string if not supported

func (*DockerDigest) Condition

func (ds *DockerDigest) Condition(source string, scm scm.ScmHandler) (pass bool, message string, err error)

Condition checks if a Docker image tag digest exists in a registry

func (*DockerDigest) ReportConfig added in v0.99.0

func (d *DockerDigest) ReportConfig() interface{}

ReportConfig returns a cleaned version of the configuration to identify the resource without any sensitive information or context specific data.

func (*DockerDigest) Source

func (ds *DockerDigest) Source(workingDir string, resultSource *result.Source) error

Source retrieves Docker image tag digest from a registry

func (*DockerDigest) Target

func (ds *DockerDigest) Target(source string, scm scm.ScmHandler, dryRun bool, resultTarget *result.Target) error

Target is not supported for the plugin Docker Digest

type Spec

type Spec struct {
	// architecture specifies the container image architecture such as `amd64`
	//
	// compatible:
	// 	* source
	// 	* condition
	//
	// default: amd64
	Architecture string `yaml:",omitempty"`
	// image specifies the container image such as `updatecli/updatecli`
	//
	// example: `updatecli/updatecli`
	//
	// compatible:
	// 	* source
	// 	* condition
	Image string `yaml:",omitempty" jsonschema:"required"`
	// tag specifies the container image tag such as `latest`
	//
	// compatible:
	// 	* source
	// 	* condition
	Tag string `yaml:",omitempty"`
	// digest specifies the container image digest such as `sha256:ce782db15ab5491c6c6178da8431b3db66988ccd11512034946a9667846952a6`
	//
	// compatible:
	// 	* condition
	//
	// default:
	// 	When used from a condition, the default value is set to the linked source output.
	Digest                string `yaml:",omitempty"`
	docker.InlineKeyChain `yaml:",inline" mapstructure:",squash"`
	// hideTag specifies if the tag should be hidden from the digest
	//
	// compatible:
	// 	* source
	//
	// default:
	// 	false
	HideTag bool `yaml:",omitempty"`
}

Spec defines a specification for a "dockerdigest" resource parsed from an updatecli manifest file

Jump to